#
# spec file for package gourmet
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gourmet
Version:        0.17.4
Release:        3.3
Summary:        Recipes Management Application
License:        GPL-2.0
Group:          Productivity/Office/Other
Url:            http://grecipe-manager.sourceforge.net
Source:         https://github.com/thinkle/%{name}/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM removed-python-shebang.patch sf#3275762 cbosdonnat@novell.com -- cleaned shebang in modules
Patch0:         removed-python-shebang.patch
BuildRequires:  ImageMagick
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  inkscape
BuildRequires:  intltool
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
Requires:       python-base
BuildRequires:  python-distutils-extra
# The gnome python module is really used, so this is not about the meta-package
Requires:       python-gnome
%if 0%{?suse_version} <= 1130
# For gtkspell
Requires:       python-gnome-extras
%else
Requires:       python-gtkspell
%endif
Requires:       python-gtk
Requires:       python-imaging
Requires:       python-poppler
Requires:       python-reportlab
Requires:       python-sqlalchemy
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%py_requires

%description
Gourmet Recipe Manager is a recipe-organizer that allows you to collect, search,
organize, and browse your recipes. Gourmet can also generate shopping lists and
calculate nutritional information. It imports Mealmaster, MasterCook and KRecipe
files and exports PDFs, webpages and other formats.

%lang_package
%prep
%setup -q -n %{name}-%{version}
%patch0 -p1

%build
python setup.py build

%install
python setup.py install --root=%{buildroot} --prefix="%{_prefix}"

# INSTALL APPLICATION ICONS
cp data/icons/scalable/apps/gourmet.svg gourmet.svg
for i in 24 32 48 64 128 256;
do
  convert -strip -density ${i}x -geometry ${i}x gourmet.svg %{name}-${i}x${i}.png
  install -Dm0644 %{name}-${i}x${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps

desktop-file-install build/share/applications/gourmet.desktop \
   --add-category="Office;ProjectManagement;" \
   --copy-name-to-generic-name

%find_lang %{name} %{?no_lang_C}
rm -fr %{buildroot}%{_datadir}/doc/%{name}

# gourmet expects to find the resource directory in %{python_sitelib}/gourmet/data rather than %{_datadir}/gourmet: see https://github.com/thinkle/gourmet/issues/762
# ln -s %{_datadir}/%{name} %{buildroot}%{python_sitelib}/%{name}/data

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-, root, root)
%doc README.md FAQ CHANGES CODING.md LICENSE ChangeLog
%{_bindir}/gourmet
%{_datadir}/gourmet/
%{_datadir}/applications/gourmet.desktop
%{python_sitelib}/gourmet/
%{python_sitelib}/*.egg-info
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/appdata
%{_datadir}/appdata/gourmet.appdata.xml

%files lang -f %{name}.lang

%changelog
* Tue Mar  8 2016 bwiedemann@suse.com
- Call convert with the -strip parameter in order to drop build
  time from png files.
* Sun Jun  8 2014 badshah400@gmail.com
- Update to version 0.17.4:
  + Introduces the use of InfoBars for import and export messages
  + #743 - When adding a recipe to a shopping list that's already
    there, increase the amounts of ingredients accordingly.
  + #756 - Fix MyCookbook import
  + #241, #287 - Fix two nasty bugs related to entering
    ingredients under a British English locale (en_GB)
  + #264 - Add a couple of new keyboard shortcuts
  + #759 - Add an AppData file to properly represent Gourmet in
    the Gnome and KDE native software centers
- Removed fdupes usage as relinking files was messing up the
  installation, causing gourmet to install but not start
- Rebase removed-python-shebang.patch for current version
- Re-enable lang_package; fdupes was somehow preventing
  generation of the .mo files
- Changes from version 0.17.3:
  + Fixed deb#744707 - Replace compressed jQuery v1.4.2 by
    uncompressed v1.11.0
  + #752 - Add My CookBook import/export plugin.
* Thu Apr 17 2014 badshah400@gmail.com
- Update to version 0.17.2:
  + Lots of upstream changes from previous packaged version, see
    /usr/share/doc/packages/gourmet/ChangeLog file for a full list
- Packaging changes:
  + Rebased removed-python-shebang.patch so that it applies
    cleanly with the updated version
  + Manually generate and install icons in the hicolor icon dir;
    introduces BuildRequires on ImageMagick, inkscape and
    hicolor-icon-theme
  + Disable lang package: no translations in upstream tarball
  + Use desktop-file-utils to install .desktop file, updating the
    categories as applicable.
* Thu Jun  9 2011 vuntz@opensuse.org
- Add explicit python-gnome Requires as the gnome module is used.
- On 11.4 and later, change python-gnome-extras Requires to
  python-gtkspell since this is the only module being used from
  python-gnome-extras.
* Tue Apr 12 2011 cbosdonnat@novell.com
- Removed sv_SE locale files for openSuse 11.2 as this locale
  isn't handled.
* Fri Apr  8 2011 cbosdonnat@novell.com
- Updated to version 0.15.9:
  + Make sure window shows up when something's added.
  + Remove threadlocal strategy. This may be a mistake, but it
    seems to clear up the commit errors numerous people were
    experiencing.
  + Make sure popup menu gets set-up for changing categories in
    shopping list.
  + Fix shopping list, and improve error messages.
  + Various bugfixes.
- Cleaned gourmet.spec with spec-cleaner
* Mon Mar 21 2011 cbosdonnat@novell.com
- Added missing python-poppler dependency
* Thu Mar 17 2011 cbosdonnat@novell.com
- Added all dependencies but the pyrtf one.
* Wed Mar 16 2011 cbosdonnat@novell.com
- Initial package for Gourmet recipe manager 0.15.8
